@@ -2,15 +2,22 @@
 # SPDX-License-Identifier: MIT
 
 # Use Joy FeatherWing to drive Gamepad.
+# https://www.adafruit.com/product/3632
+# https://learn.adafruit.com/joy-featherwing
+
+# You must add a gamepad HID device inside your boot.py file
+# in order to use this example.
+# See this Learn Guide for details:
+# https://learn.adafruit.com/customizing-usb-devices-in-circuitpython/hid-devices#custom-hid-devices-3096614-9
 
 import time
 
 import board
 import busio
 from micropython import const
-import adafruit_seesaw
+from adafruit_seesaw.seesaw import Seesaw
 import usb_hid
-from adafruit_hid.gamepad import Gamepad
+from hid_gamepad import Gamepad
 
 
 def range_map(value, in_min, in_max, out_min, out_max):
@@ -32,7 +39,7 @@ button_mask = const(
 
 i2c = busio.I2C(board.SCL, board.SDA)
 
-ss = adafruit_seesaw.Seesaw(i2c)
+ss = Seesaw(i2c)
 
 ss.pin_mode_bulk(button_mask, ss.INPUT_PULLUP)
 
